@@ -1,7 +1,10 @@
 .onAttach <- function(libname, pkgname) {
     # startup message
     packageStartupMessage(
-        paste("\nYou are using rkeops version", packageVersion("rkeops"), "\n"))
+        paste(
+            "\nYou are using rkeops version", packageVersion("rkeops"), "\n"
+        )
+    )
 }
 
 .onLoad <- function(libname, pkgname) {
@@ -9,6 +12,8 @@
     if(is_installed() & check_os(onLoad=TRUE)) {
         # set up rkeops global options
         set_rkeops_options()
+        # use cpu by default
+        use_cpu()
     }
 }
 
